/*******************************************************************************
* Title: ADC_Setup.c                                                           
* Version: 1.0                                                                 
* Author: Jeff Nybo                                                            
* Date: April 23, 2014                                                      
*                                                                              
* Description:                                                                 
* This file contains all the functions that are needed in order to initialize  
* and control the operation of the ADC module.                                 
*******************************************************************************/

#ifndef ADC_SETUP_C
#define ADC_SETUP_C

#include "Main_Includes.h"
#include "ADC_Setup.h"

/*******************************************************************************
* Function: ADC_Init(void)                                              
*                                                                              
* Variables:                                                                   
* setup -> Stores the setup values of the ADC module                           
*                                                                              
* Description:                                                                 
* This function will initialize the ADC module according to the specifications 
* that the user has set.                                                       
*******************************************************************************/
void ADC_Init(void)
{
  //Turn on, auto sample start, auto-convert
  AD1CON1 = 0x80E4;

  //Vref+, Vref-, int every conversion, MUXA only
  AD1CON2 = 0x0000;

  //31 Tad auto-sample, Tad = 5*Tcy
  AD1CON3 = 0x8C05;
  
  //Allocate two WORDs in buffer
  AD1CON4 = 1;

  //No sequential scanning
  AD1CSSL = 0;
  
  //Choose channel
  AD1CHS0 = 4;  
}

/*******************************************************************************
* Function: ADC_Read(void)                                                     
*                                                                              
* Variables:                                                                   
* N/A                                                                          
*                                                                              
* Description:                                                                 
* This function will read the ADC value on whichever ANx Channel is currently 
* selected. It will then return the 10-Bit value that was read on the ADC pin as
* a 16-Bit variable.                                
*******************************************************************************/
UINT16 ADC_Read(void)
{
  //Begin ADC sample
  _SAMP = 1;
  
  //Wait for AD Conversion to finish
  while (!AD1CON1bits.DONE);
  
  //Return the ADC value
  return ADC1BUF0; 
}

#endif
