/*******************************************************************************
* Title: HT1632C_Setup.h                                                        
* Version: 1.0                                                                  
* Author: Jeff Nybo                                                             
* Date: April 23, 2014                                                         
*                                                                               
* Description:                                                                  
* This file contains the function prototypes and definitions which are used to  
* control one or more HT1632C 32x8 LED Drivers.                                  
*******************************************************************************/

#ifndef HT1632C_SETUP_H
#define HT1632C_SETUP_H

/*************************************************
*                   Constants                    *
*************************************************/
#define HT1632_AMOUNT     2

//As I have not updated the library yet, you must define the amount of
//HT1632C chips that you are using and add their CS pins
#define HT1632_CS1        _LATD10 
#define HT1632_CS2        _LATD11      

//Signal and data line connections
#define HT1632_RD         _LATD9 
#define HT1632_WR         _LATD8 
#define HT1632_DATA       _LATG2 
#define HT1632_OSC        PORTDbits.RD5 
#define HT1632_SYNC       PORTDbits.RD0 
             
//All commands written to the chip contain a 3 bit ID code before the data
#define HT1632_ID_CMD            4		// ID => 100 - Commands 
#define HT1632_ID_RD             6		// ID => 110 - Read RAM 
#define HT1632_ID_WR             5		// ID => 101 - Write RAM 

//Configuration Options
#define HT1632_SYSDIS         0x00	
#define HT1632_SYSON          0x01	
#define HT1632_LEDOFF         0x02	 
#define HT1632_LEDON          0x03	
#define HT1632_BLOFF          0x08	
#define HT1632_BLON           0x09	
#define HT1632_SLVMD          0x10	
#define HT1632_MSTMD          0x18	
#define HT1632_EXTCLK         0x1C	 
#define HT1632_COMS00         0x20	 
#define HT1632_COMS01         0x24	 
#define HT1632_COMS10         0x28	 
#define HT1632_COMS11         0x2C	 
#define HT1632_PWM            0xA0	

/*************************************************
*               Global Variables                 *
*************************************************/

/*************************************************
*                   Macros                       *
*************************************************/
#define HT1632_PULSE(x)    {x = 0; x = 1;}

/*************************************************
*              Function Prototypes               *
*************************************************/
void HT1632_Init(void);
void HT1632_Chip_Select(INT8 selection);
void HT1632_Send_CMD(INT8 chip, UINT8 cmd);
void HT1632_Set_PWM(UINT8 value);
void HT1632_Write_Bits(UINT8 amt, UINT8 bits);
void HT1632_Send_Data(INT8 chip, UINT8 addr, UINT8 data);

#endif
