/*******************************************************************************
* Title: TLC5940_Setup.h                                                       
* Version: 1.0                                                                 
* Author: Jeff Nybo                                                            
* Date: April 23, 2014                                                     
*                                                                              
* Description:                                                                 
* This file contains the functions and commands that are used to address and                                                                             
* control a specified amount of TLC5940's.                                     
*******************************************************************************/
 
#ifndef TLC5940_SETUP_H
#define TLC5940_SETUP_H
   
#include "Delay_setup.h"    

/*************************************************
*                Global Variables                *
*************************************************/ 
#define WAIT_XLAT       FLAG1.b0
#define TLC_UPDATE      FLAG1.b1    

/*************************************************
*                   Constants                    *
*************************************************/ 
//TLC5940 SPI Control Lines
#define TLC_ENA         _LATC2
#define TLC_MOSI        _LATG8
#define TLC_MISO        _LATG7
#define TLC_SCK         _LATG6

//TLC5940 Signal Control Lines
#define TLC_XLAT        _LATG13
#define TLC_BLANK       _LATG12
#define TLC_VPRG        _LATG14
#define TLC_DCPRG       _LATG0
#define TLC_GSCLK       _LATD1

//Number of TLC5940 chips on the circuit
#define TLC_CHIPS       5

/*************************************************
*                   Macros                       *
*************************************************/
#define PULSE(x)    {x = 1; Nop(); Nop(); Nop(); Nop(); x = 0;}

/*************************************************
*              Function Prototypes               *
*************************************************/ 
void TLC5940_Update(void);        
void TLC5940_Init(void);
void XLAT_Interrupt(void);
void Set_Grayscale(void);
void Set_Initial_Grayscale(void);
void Dot_Correction(void);
void Clear_Outputs(void);
void Fill_Outputs(void);
void Send_BB(UINT8 data);

#endif
