/*******************************************************************************
* Title: Typedefs.h                                                                       
* Version: 1.0                                                                 
* Author: Jeff Nybo                                                            
* Date: April 23, 2014                                                                       
*                                                                              
* Description:                                                                 
* This file contains all of the typedefs and some constants that are used 
* throughout the project.                                                                             
*******************************************************************************/

#ifndef TYPEDEFS_H
#define TYPEDEFS_H

/*************************************************
*                 Quick Keywords                 *
*************************************************/
typedef unsigned long int UINT32;
typedef unsigned long int DWORD;
typedef signed long int INT32;

typedef unsigned int UINT16;
typedef unsigned int WORD;
typedef signed int INT16;

typedef unsigned char UINT8;
typedef unsigned char BYTE;
typedef signed char INT8;

/*************************************************
*                  Constants                     *
*************************************************/ 
#define FOSC  80000000LL
#define FCYC  (FOSC / 2)

#define TOSC  (1 / FOSC)
#define TCYC  (2 / FOSC)

#define HIGH  0x01
#define LOW   0x00

#define TRUE  0x01
#define FALSE 0x00

#define ON    0x01
#define OFF   0x00

//Defines the array size of the seq[x] variables
#define SEQ_AMOUNT		50

//The 11 color defaults
#define BLACK               0  
#define RED                 1 
#define GREEN               2
#define BLUE                3
#define ORANGE              4
#define PINK                5
#define CYAN                6
#define MAGENTA             7
#define YELLOW              8
#define VIOLET              9
#define WHITE               10

/*************************************************
*                   Macros                       *
*************************************************/
#define BitSet(var,bitno) (var|=(1<<bitno))
#define BitClr(var,bitno) (var&=~(1<<bitno))
#define BitTst(var,bitno) (var&(1<<bitno))

/*************************************************
*                Data Structures                 *
*************************************************/
typedef struct
{
  float red;
  float green;
  float blue;
} RGB; 

typedef struct
{
  float red;
  float green;
  float blue;
  UINT16 delay;
} RGB_FADE; 

typedef struct
{
  float value;
  UINT16 delay;
} LED_RING; 

//Bit Variables
typedef union tag8bits{
   struct {
     UINT8 all;
   };
   struct {  
      unsigned b0:1;    
      unsigned b1:1;    
      unsigned b2:1;    
      unsigned b3:1;
      unsigned b4:1;  
      unsigned b5:1;    
      unsigned b6:1;
      unsigned b7:1;            
   };
 }T8_FLAG;

typedef union tag16bits{
   struct {
     UINT16 all;
   };
   struct {  
      unsigned b0:1;    
      unsigned b1:1;    
      unsigned b2:1;    
      unsigned b3:1;
      unsigned b4:1;  
      unsigned b5:1;    
      unsigned b6:1;
      unsigned b7:1;
      unsigned b8:1;    
      unsigned b9:1;    
      unsigned b10:1;    
      unsigned b11:1;
      unsigned b12:1;  
      unsigned b13:1;    
      unsigned b14:1;
      unsigned b15:1;              
   };
 }T16_FLAG;

typedef union tag32bits{
   struct {
     UINT32 all;
   };
   struct {  
      unsigned b0:1;    
      unsigned b1:1;    
      unsigned b2:1;    
      unsigned b3:1;
      unsigned b4:1;  
      unsigned b5:1;    
      unsigned b6:1;
      unsigned b7:1;
      unsigned b8:1;    
      unsigned b9:1;    
      unsigned b10:1;    
      unsigned b11:1;
      unsigned b12:1;  
      unsigned b13:1;    
      unsigned b14:1;
      unsigned b15:1;   
      unsigned b16:1;    
      unsigned b17:1;    
      unsigned b18:1;    
      unsigned b19:1;    
      unsigned b20:1;    
      unsigned b21:1;    
      unsigned b22:1;    
      unsigned b23:1;    
      unsigned b24:1;    
      unsigned b25:1;    
      unsigned b26:1;    
      unsigned b27:1;    
      unsigned b28:1;    
      unsigned b29:1;    
      unsigned b30:1;    
      unsigned b31:1;             
   };
 }T32_FLAG;

#endif
